% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat-peaks.R
\name{stat_peaks}
\alias{stat_peaks}
\alias{stat_valleys}
\title{Find and label local maxima (peaks) or minima (valleys).}
\usage{
stat_peaks(mapping = NULL, data = NULL, geom = "point", span = 5,
  ignore_threshold = 0, strict = FALSE, label.fmt = "\%.4g",
  x.label.fmt = NULL, y.label.fmt = label.fmt, position = "identity",
  na.rm = FALSE, show.legend = FALSE, inherit.aes = TRUE, ...)

stat_valleys(mapping = NULL, data = NULL, geom = "point", span = 5,
  ignore_threshold = 0, strict = FALSE, label.fmt = "\%.4g",
  x.label.fmt = NULL, y.label.fmt = label.fmt, position = "identity",
  na.rm = FALSE, show.legend = FALSE, inherit.aes = TRUE, ...)
}
\arguments{
\item{mapping}{The aesthetic mapping, usually constructed with
\code{\link[ggplot2]{aes}} or \code{\link[ggplot2]{aes_string}}. Only needs
to be set
 at the layer level if you are overriding the plot defaults.}

\item{data}{A layer specific dataset - only needed if you want to override
the plot defaults.}

\item{geom}{The geometric object to use display the data}

\item{span}{a peak is defined as an element in a sequence which is greater
than all other elements within a window of width span centered at that
element. The default value is 5, meaning that a peak is bigger than two
consecutive neighbors on each side. A \code{NULL} value for \code{span}
is taken as a span covering the whole of the data range.}

\item{ignore_threshold}{numeric value between 0.0 and 1.0 indicating the size
threshold below which peaks will be ignored.}

\item{strict}{logical flag: if TRUE, an element must be strictly greater than
all other values in its window to be considered a peak. Default: FALSE.}

\item{label.fmt}{character  string giving a format definition for converting
values into character strings by means of function \code{\link{sprintf}}.}

\item{x.label.fmt}{character  string giving a format definition for converting
$x$-values into character strings by means of function \code{\link{sprintf}}
or \code{\link{strftime}}.}

\item{y.label.fmt}{character  string giving a format definition for converting
$y$-values into character strings by means of function \code{\link{sprintf}}.}

\item{position}{The position adjustment to use for overlapping points
on this layer}

\item{na.rm}{a logical value indicating whether NA values should be
stripped before the computation proceeds.}

\item{show.legend}{logical. Should this layer be included in the legends?
\code{NA}, the default, includes if any aesthetics are mapped.
\code{FALSE} never includes, and \code{TRUE} always includes.}

\item{inherit.aes}{If \code{FALSE}, overrides the default aesthetics,
rather than combining with them. This is most useful for helper functions
that define both data and aesthetics and shouldn't inherit behaviour from
the default plot specification, e.g. \code{\link[ggplot2]{borders}}.}

\item{...}{other arguments passed on to \code{\link[ggplot2]{layer}}. This can
include aesthetics whose values you want to set, not map. See
\code{\link[ggplot2]{layer}} for more details.}
}
\description{
\code{stat_peaks} finds at which x positions local y maxima are located and
\code{stat_valleys} finds at which x positions local y minima are located.
Both stats return x and y numeric values for peaks or valleys and formatted
character labels. The formatting is determined by a format string suitable
for \code{sprintf()}.
}
\details{
These stats use \code{geom_point} by default as it is the geom most
  likely to work well in almost any situation without need of tweaking. The
  default aesthetics set by these stats allow their direct use with
  \code{geom_text}, \code{geom_label}, \code{geom_line}, \code{geom_rug},
  \code{geom_hline} and \code{geom_vline}. The formatting of the labels
  returned can be controlled by the user.
}
\note{
These stats check the scale of the \code{x} aesthetic and if is Datetime they
  correctly generate the labels by transforming the numeric x values to
  POSIXct objects, in which case the \code{x.label.fmt} must be suitable for
  \code{strftime()} rather than for \code{sprintf()}.
These stats work nicely together with geoms
  \code{\link[ggrepel]{geom_text_repel}} and
  \code{\link[ggrepel]{geom_label_repel}} from package
  \code{\link[ggrepel]{ggrepel}} to solve the problem of overlapping labels
  by displacing them. Alternatively, to discard overlapping labels use
  \code{check_overlap = TRUE} as argument to \code{geom_text}.
 By default the labels are character values suitable to be plotted as is, but
 with a suitable \code{label.fmt} labels suitable for parsing by the geoms
 (e.g. into expressions containing Greek letters, super- or subscripts,
 maths symbols or maths constructs) can be also easily obtained.
}
\section{Computed variables}{

\describe{
  \item{x}{x-value at the peak (or valley) as numeric}
  \item{y}{y-value at the peak (or valley) as numeric}
  \item{x.label}{x-value at the peak (or valley) as character}
  \item{y.label}{y-value at the peak (or valley) as character}
}
}

\examples{
library(ggplot2)
lynx.df <- data.frame(year = as.numeric(time(lynx)), lynx = as.matrix(lynx))
ggplot(lynx.df, aes(year, lynx)) + geom_line() +
  stat_peaks(colour = "red") +
  stat_valleys(colour = "blue")
ggplot(lynx.df, aes(year, lynx)) + geom_line() +
  stat_peaks(colour = "red") +
  stat_peaks(colour = "red", geom = "rug")

}
\seealso{
Other peaks and valleys functions: \code{\link{find_peaks}}
}
